==> hibernate-search-engine-4.1.1.Final-redhat-1-sources.jar: org/hibernate/search/indexes/serialization/spi/LuceneWorkSerializer.java <==
/* 
 * Hibernate, Relational Persistence for Idiomatic Java
 * 
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.search.indexes.serialization.spi;

import java.util.List;

import org.hibernate.search.backend.LuceneWork;

/**
 * For clustering we need some way to serialize the LuceneWork(s)
 * to the other nodes.
 * 
 * @author Sanne Grinovero <sanne@hibernate.org> (C) 2011 Red Hat Inc.
 */
public interface LuceneWorkSerializer {

	/**
	 * Convert a List of LuceneWork into a byte[]
	 */
	byte[] toSerializedModel(List<LuceneWork> works);

	/**
	 * Convert a byte[] to a List of LuceneWork
	 */
	List<LuceneWork> toLuceneWorks(byte[] data);

}

==> hibernate-search-engine-4.6.1.Final-redhat-1-sources.jar: org/hibernate/search/indexes/serialization/spi/LuceneWorkSerializer.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.search.indexes.serialization.spi;

import java.util.List;

import org.hibernate.search.backend.LuceneWork;

/**
 * For clustering we need some way to serialize the {@code LuceneWork} instances.
 * to the other nodes.
 *
 * @author Sanne Grinovero <sanne@hibernate.org> (C) 2011 Red Hat Inc.
 */
public interface LuceneWorkSerializer {

	/**
	 * Convert a List of LuceneWork into a byte[]
	 */
	byte[] toSerializedModel(List<LuceneWork> works);

	/**
	 * Convert a byte[] to a List of LuceneWork
	 */
	List<LuceneWork> toLuceneWorks(byte[] data);

	/**
	 * @return a short label of this implementation and optionally version
	 */
	String describeSerializer();

}
